@@ -10,7 +10,7 @@ if [ $# != 1 ] ; then
 	echo install-pre.sh vserver
 else
 	mkdir -p /etc/vservers
-	mkdir /vservers 2>/dev/null && chmod 000 /vservers/.
+	mkdir -p /vservers 2>/dev/null
 	VROOT=/vservers/$1
 	rm -fr $VROOT/dev
 	mkdir -p $VROOT/dev && chmod 755 $VROOT/dev
@@ -22,5 +22,7 @@ else
 	vserver_mknod $VROOT/dev/urandom c 1 9 644
 	vserver_mknod $VROOT/dev/tty c 5 0 666
 	vserver_mknod $VROOT/dev/ptmx c 5 2 666
+	# We fake this device to help some package managers
+	touch $VROOT/dev/hdv1
 fi
 
